@@ -216,7 +216,7 @@ theme_economist <- function(base_size = 10, base_family = "sans",
           # axis.ticks.length = unit( -1/32, "in"),
           axis.ticks.length = unit( -base_size * 0.5, "points"),
           legend.background = element_rect(linetype = 0),
-          legend.margin = unit(base_size * 1.5, "points"),
+          legend.spacing = unit(base_size * 1.5, "points"),
           legend.key = element_rect(linetype = 0),
           legend.key.size = unit(1.2, "lines"),
           legend.key.height = NULL,
@@ -234,7 +234,7 @@ theme_economist <- function(base_size = 10, base_family = "sans",
           panel.border = element_blank(),
           panel.grid.major = element_line(colour = "white", size = rel(1.75)),
           panel.grid.minor = element_blank(),
-          panel.margin = unit(0.25, "lines"),
+          panel.spacing = unit(0.25, "lines"),
           strip.background = element_rect(fill = bgcolors["ebg"],
                                           colour = NA, linetype = 0),
           strip.text = element_text(size = rel(1.25)),
