@@ -29,7 +29,7 @@ theme_hc <- function(base_size = 12,
                title = element_text(hjust = 0.5),
                axis.title.x = element_text(hjust = 0.5),
                axis.title.y = element_text(hjust = 0.5),
-               panel.grid.major.y = element_line(color = "gray"),
+               panel.grid.major.y = element_line(colour = "#D8D8D8"),
                panel.grid.minor.y = element_blank(),
                panel.grid.major.x = element_blank(),
                panel.grid.minor.x = element_blank(),
@@ -44,7 +44,7 @@ theme_hc <- function(base_size = 12,
                         title = element_text(colour = "#FFFFFF"),
                         axis.title.x = element_text(colour = "#A0A0A3"),
                         axis.title.y = element_text(colour = "#A0A0A3"),
-                        panel.grid.major.y = element_line(color = "gray"),
+                        panel.grid.major.y = element_line(colour = "#707073"),
                         legend.title = element_text(colour = "#A0A0A3")))
   }
   ret
