@@ -27,7 +27,7 @@ theme_map <- function(base_size = 9, base_family = "") {
           panel.background = element_blank(),
           panel.border = element_blank(),
           panel.grid = element_blank(),
-          panel.margin = unit(0, "lines"),
+          panel.spacing = unit(0, "lines"),
           plot.background = element_blank(),
           legend.justification = c(0, 0),
           legend.position = c(0, 0))
